@@ -33,7 +33,6 @@ static gboolean item_event_ok (GooCanvasItem  *item,
 			       GooCanvasItem  *target,
 			       GdkEventButton *event,
 			       gchar *data);
-void gc_about_stop (void);
 
 /*
  * Do all the bar display and register the events
@@ -42,7 +41,6 @@ void gc_about_start ()
 {
   GdkPixbuf   *pixmap = NULL;
   gdouble y_start = 0;
-  gdouble x_start = 0;
   gint y = 0;
   GooCanvasItem *item;
 
@@ -61,10 +59,7 @@ void gc_about_start ()
   gc_board_pause(TRUE);
 
   if(rootitem)
-  {
-    gc_about_stop();
     return;
-  }
 
   gc_bar_hide (TRUE);
 
@@ -79,7 +74,6 @@ void gc_about_start ()
 
   GooCanvasBounds bounds;
   goo_canvas_item_get_bounds(item, &bounds);
-  x_start = bounds.x1;
   y_start = bounds.y1;
 
   y = bounds.y2 - 26;
