@@ -56,71 +56,73 @@ static gint y_flag_start;
 
 static gchar *linguas[] = {
   "",			N_("Your system default"),
-  "af_ZA.UTF-8", 	N_("Afrikaans"),
-  "am_ET.UTF-8", 	N_("Amharic"),
-  "ar_AE.UTF-8", 	N_("Arabic"),
-  "ast_ES.UTF-8", 	N_("Asturian"),
-  "az_AZ.UTF-8", 	N_("Turkish (Azerbaijan)"),
-  "bg_BG.UTF-8",	N_("Bulgarian"),
+  "af_ZA.UTF-8",	N_("Afrikaans"),
+  "sq_AL.UTF-8",	N_("Albanian"),
+  "am_ET.UTF-8",	N_("Amharic"),
+  "ar_AE.UTF-8",	N_("Arabic"),
+  "ast_ES.UTF-8",	N_("Asturian"),
+  "eu_ES.UTF-8",	N_("Basque"),
   "br_FR.UTF-8",	N_("Breton"),
+  "bg_BG.UTF-8",	N_("Bulgarian"),
   "ca_ES.UTF-8",	N_("Catalan"),
+  "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
+  "zh_TW.UTF-8",	N_("Chinese (Traditional)"),
+  "hr_HR.UTF-8",	N_("Croatian"),
   "cs_CZ.UTF-8",	N_("Czech Republic"),
-  "da_DK.UTF-8", 	N_("Danish"),
-  "de_DE.UTF-8", 	N_("German"),
+  "da_DK.UTF-8",	N_("Danish"),
+  "nl_NL.UTF-8",	N_("Dutch"),
   "dz_BT.UTF-8",	N_("Dzongkha"),
-  "el_GR.UTF-8", 	N_("Greek"),
   "en_CA.UTF-8",	N_("English (Canada)"),
   "en_GB.UTF-8",	N_("English (Great Britain)"),
   "en_US.UTF-8",	N_("English (United States)"),
-  "es_ES.UTF-8", 	N_("Spanish"),
-  "eu_ES.UTF-8",	N_("Basque"),
-  "fa_IR.UTF-8", 	N_("Persian"),
-  "fi_FI.UTF-8", 	N_("Finnish"),
-  "fr_FR.UTF-8", 	N_("French"),
-  "ga_IE.UTF-8", 	N_("Irish (Gaelic)"),
+  "fi_FI.UTF-8",	N_("Finnish"),
+  "fr_FR.UTF-8",	N_("French"),
+  "ka_GE.UTF-8",	N_("Georgian"),
+  "de_DE.UTF-8",	N_("German"),
+  "el_GR.UTF-8",	N_("Greek"),
   "gu_IN.UTF-8",	N_("Gujarati"),
   "he_IL.UTF-8",	N_("Hebrew"),
   "hi_IN.UTF-8",	N_("Hindi"),
-  "hr_HR.UTF-8",	N_("Croatian"),
   "hu_HU.UTF-8",	N_("Hungarian"),
   "id_ID.UTF-8",	N_("Indonesian"),
-  "it_IT.UTF-8", 	N_("Italian"),
+  "ga_IE.UTF-8",	N_("Irish (Gaelic)"),
+  "it_IT.UTF-8",	N_("Italian"),
   "ja_JP.UTF-8",	N_("Japanese"),
-  "ka_GE.UTF-8",        N_("Georgian"),
-  "ko_KR.UTF-8",        N_("Korean"),
+  "rw_RW.UTF-8",	N_("Kinyarwanda"),
+  "ko_KR.UTF-8",	N_("Korean"),
   "lt_LT.UTF-8",	N_("Lithuanian"),
   "mk_MK.UTF-8",	N_("Macedonian"),
+  "ms_MY.UTF-8",	N_("Malay"),
   "ml_IN.UTF-8",	N_("Malayalam"),
   "mr_IN.UTF-8",	N_("Marathi"),
-  "ms_MY.UTF-8",	N_("Malay"),
-  "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
+  "sr_ME.UTF-8",	N_("Montenegrin"),
   "ne_NP.UTF-8",	N_("Nepal"),
-  "nl_NL.UTF-8",	N_("Dutch"),
+  "nb_NO.UTF-8",	N_("Norwegian Bokmal"),
   "nn_NO.UTF-8",	N_("Norwegian Nynorsk"),
   "oc_FR.UTF-8",	N_("Occitan (languedocien)"),
-  "pa_IN.UTF-8",	N_("Punjabi"),
+  "fa_IR.UTF-8",	N_("Persian"),
   "pl_PL.UTF-8",	N_("Polish"),
   "pt_BR.UTF-8",	N_("Portuguese (Brazil)"),
   "pt_PT.UTF-8",	N_("Portuguese"),
+  "pa_IN.UTF-8",	N_("Punjabi"),
   "ro_RO.UTF-8",	N_("Romanian"),
   "ru_RU.UTF-8",	N_("Russian"),
-  "rw_RW.UTF-8",	N_("Kinyarwanda"),
+  "sr@Latn_YU.ISO-8859-2",	N_("Serbian (Latin)"),
+  "sr_YU.UTF-8",	N_("Serbian"),
   "sk_SK.UTF-8",	N_("Slovak"),
   "sl_SI.UTF-8",	N_("Slovenian"),
   "so_SO.UTF-8",	N_("Somali"),
-  "sq_AL.UTF-8",	N_("Albanian"),
-  "sr@Latn_YU.ISO-8859-2",	N_("Serbian (Latin)"),
-  "sr_YU.UTF-8",	N_("Serbian"),
+  "es_ES.UTF-8",	N_("Spanish"),
   "sv_FI.UTF-8",	N_("Swedish"),
   "ta_IN.UTF-8",	N_("Tamil"),
   "th_TH.UTF-8",	N_("Thai"),
+  "az_AZ.UTF-8",	N_("Turkish (Azerbaijan)"),
   "tr_TR.UTF-8",	N_("Turkish"),
   "uk_UA.UTF8",		N_("Ukrainian"),
   "ur_PK.UTF-8",	N_("Urdu"),
   "vi_VN.UTF-8",	N_("Vietnamese"),
   "wa_BE.UTF-8",	N_("Walloon"),
-  "zh_CN.UTF-8",	N_("Chinese (Simplified)"),
-  "zh_TW.UTF-8",        N_("Chinese (Traditional)"),
+  "zu_ZA.UTF-8",	N_("Zulu"),
   NULL, NULL
 };
 
@@ -162,10 +164,7 @@ gc_config_start ()
   gc_board_pause(TRUE);
 
   if(rootitem)
-  {
-    gc_config_stop();
     return;
-  }
 
   gc_bar_hide(TRUE);
 
@@ -221,6 +220,22 @@ gc_config_start ()
 		    x_flag_start + 5,
 		    y_start - pixmap_width/2);
 
+  /* A repeat icon to reset the selection */
+  item = goo_canvas_svg_new (rootitem,
+			     gc_skin_rsvg_get(),
+			     "svg-id", "#REPEAT",
+			     NULL);
+    goo_canvas_item_get_bounds(item, &bounds);
+    double zoom = 0.65;
+    goo_canvas_item_scale(item, zoom, zoom);
+    goo_canvas_item_translate(item,
+			      (-1 * bounds.x1 + x_flag_start - 340) * zoom,
+			      (-1 * bounds.y1 + y_start - 120) * zoom);
+  g_signal_connect(item, "button_press_event",
+		   (GtkSignalFunc) item_event_ok,
+		   "locale_reset");
+  gc_item_focus_init(item, NULL);
+
   /*
    * The current locale is the one found in the config file
    */
@@ -727,6 +742,15 @@ item_event_ok(GooCanvasItem *item,
 		    "text", gc_locale_get_name(current_locale),
 		    NULL);
 
+      set_locale_flag(current_locale);
+    }
+  else if(!strcmp((char *)data, "locale_reset"))
+    {
+      current_locale = linguas[0];
+      g_object_set (G_OBJECT(item_locale_text),
+		    "text", gc_locale_get_name(current_locale),
+		    NULL);
+
       set_locale_flag(current_locale);
     }
   else if(!strcmp((char *)data, "timer_previous"))
