@@ -56,6 +56,13 @@ gc_sound_init()
 
 }
 
+static gboolean
+run_sound_callback(gpointer data)
+{
+  gc_sound_callback((gchar *)data);
+  return FALSE; /* remove idle callback */
+}
+
 static gboolean
 fx_bus(GstBus* bus, GstMessage* msg, gpointer data)
 {
@@ -64,7 +71,8 @@ fx_bus(GstBus* bus, GstMessage* msg, gpointer data)
     case GST_MESSAGE_EOS:
       g_warning("fx_bus: EOS START");
       gc_sound_fx_close();
-      gc_sound_callback((gchar *)data);
+      /* holds GStreamer locks */
+      g_idle_add(run_sound_callback, data);
       fx_play();
       g_warning("fx_bus: EOS END");
       break;
@@ -117,7 +125,7 @@ gc_sound_fx_close()
 void
 gc_sound_bg_reopen()
 {
-  if(gc_prop_get()->music && !gc_prop_get()->music_paused)
+  if(gc_prop_get()->music)
     bg_play(NULL);
 }
 
@@ -176,9 +184,6 @@ gc_sound_fx_resume()
 gpointer
 bg_play(gpointer dummy)
 {
-  if (bg_pipeline)
-    return NULL;
-
   gchar *absolute_file = gc_sound_get_next_music();
 
   if (!absolute_file)
